
============================================
 API Reference — Planetary reference frames
============================================

.. testsetup::

   from pprint import pprint
   from skyfield.planetarylib import PlanetaryConstants

.. currentmodule:: skyfield.planetarylib

.. autoclass:: PlanetaryConstants
   :members:

.. autoclass:: Frame
   :members:
